@@ -12,7 +12,7 @@
 
 using namespace Attica;
 
-class Content::Private : public QSharedData
+class Q_DECL_HIDDEN Content::Private : public QSharedData
 {
 public:
     QString m_id;
@@ -176,11 +176,12 @@ QList<Attica::DownloadDescription> Attica::Content::downloadUrlDescriptions() co
     QList<Attica::DownloadDescription> descriptions;
     QMap<QString, QString>::const_iterator iter = d->m_extendedAttributes.constBegin();
     while (iter != d->m_extendedAttributes.constEnd()) {
-        QString key = iter.key();
-        if (key.startsWith(QLatin1String("downloadname"))) {
+        const QString &key = iter.key();
+        static const QLatin1String tag("downloadname");
+        if (key.startsWith(tag)) {
             bool ok;
             // remove "downloadlink", get the rest as number
-            int num = key.rightRef(key.size() - 12).toInt(&ok);
+            const int num = QStringView(key).right(key.size() - tag.size()).toInt(&ok);
             if (ok) {
                 // check if the download actually has a name
                 if (!iter.value().isEmpty()) {
@@ -232,7 +233,7 @@ QList<HomePageEntry> Attica::Content::homePageEntries()
         if (key.startsWith(QLatin1String("homepagetype"))) {
             bool ok;
             // remove "homepage", get the rest as number
-            int num = key.rightRef(key.size() - 12).toInt(&ok);
+            const int num = QStringView(key).right(key.size() - 12).toInt(&ok);
             if (ok) {
                 // check if the homepage actually has a valid type
                 if (!iter.value().isEmpty()) {
